@@ -4,5 +4,5 @@ use nxui::window::Frame;
 
 fn main() {
     nxui::initialize();
-    MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_YESNO).show(Frame::default());
+    MessageBox::new("Hello NXUI!","This is a test",DIALOGSTYLE_INFORMATION,BUTTONSTYLE_YESNO).show(Frame::default());
 }
\ No newline at end of file
