@@ -4,11 +4,11 @@
 use crate::window::Frame;
 
 #[cfg(windows)]
-pub struct MessageBox {
+pub struct MessageBox<'a> {
     /// Message to be displayed
-    pub title: String,
+    pub title: &'a str,
     /// Message to be displayed
-    pub message: String,
+    pub message: &'a str,
     /// Dialog style
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE,
     /// Dialog button style
@@ -16,11 +16,11 @@ pub struct MessageBox {
 }
 
 #[cfg(unix)]
-pub struct MessageBox {
+pub struct MessageBox<'a> {
     /// Message to be displayed
-    pub title: String,
+    pub title: &'a str,
     /// Message to be displayed
-    pub message: String,
+    pub message: &'a str,
     /// Dialog style
     pub style: gtk::MessageType,
     /// Dialog button style
@@ -28,11 +28,11 @@ pub struct MessageBox {
 }
 
 #[cfg(windows)]
-impl MessageBox {
+impl<'a> MessageBox<'a> {
     /// Create a new MessageBox.
     pub fn new(
-        title: String,
-        message: String,
+        title: &'a str,
+        message: &'a str,
         style: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE,
         button_style: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE,
     ) -> Self {
@@ -80,11 +80,11 @@ impl MessageBox {
 }
 
 #[cfg(unix)]
-impl MessageBox {
+impl <'a> MessageBox<'a> {
     /// Create a new MessageBox.
     pub fn new(
-        title: String,
-        message: String,
+        title: &'a str,
+        message: &'a str,
         style: gtk::MessageType,
         button_style: gtk::ButtonsType,
     ) -> Self {
@@ -112,14 +112,14 @@ impl MessageBox {
         gtk::init().expect("Failed to initialize gtk.");
         let window = gtk::Window::new(gtk::WindowType::Toplevel);
 
-        window.set_title(self.title.as_str());
+        window.set_title(self.title);
 
         let dialog = gtk::MessageDialog::new(
             Some(&window),
             gtk::DialogFlags::empty(),
             self.style,
             self.button_style,
-            self.message.as_str(),
+            self.message,
         );
         let result = dialog.run();
         unsafe {
