@@ -99,12 +99,12 @@ pub fn create_new_app(application: Box<dyn Application>) {
     });
     let frame = Frame::new(window.clone());
     info!("Frame has been created.");
-    nfo!("UI Phase");
+    info!("UI Phase");
     application.ui(frame);
 
     window.show_all();
 
     gtk::main();
-    nfo!("UI Exit");
+    info!("UI Exit");
     application.exit();
 }
\ No newline at end of file
